import preload from './utils/preload';

preload();

import express from 'express';
import logger from './utils/logger';
import pinoHttp from 'pino-http';
import router from './routers';

const app = express();
const port = process.env.PORT || 25930;

// 中间件
app.use(pinoHttp({
  useLevel: 'debug',
  logger,
}));
app.use(express.json());
app.use(express.urlencoded({ extended: true }));

app.use('/api', router);

// 错误处理中间件
app.use((err: Error, req: express.Request, res: express.Response, next: express.NextFunction) => {
  logger.error(err);
  res.status(500).json({ code: 500, message: '服务内部错误' });
});

// 启动服务器
app.listen(port, () => {
  logger.info(`服务运行在 http://localhost:${port}`);
});
